/* $Id: XNotesPlus.h,v 1.9 2005/06/24 15:35:24 mjhammel Exp $ */
/*========================================================================
 *  Copyright (c) Michael J. Hammel 1995-2001
 *========================================================================
 *              FILE NAME: XNotesPlus.h
 *            DESCRIPTION: declarations for XNotesPlus.
 *  SOFTWARE DEPENDENCIES: gtk, gdk, glib, Xlib
 *  HARDWARE DEPENDENCIES: 
 *                  NOTES: 
 *
 * SPECIAL CONSIDERATIONS:
 * This file is easiest to read with tabstops set to 3
 *
 *========================================================================
 *
 * MODIFICATION HISTORY:
 * $Log: XNotesPlus.h,v $
 * Revision 1.9  2005/06/24 15:35:24  mjhammel
 * Added TAG_HILITE_YELLOW.
 *
 * Revision 1.8  2005/06/23 17:25:32  mjhammel
 * Added pn_textbuffer to StickyNote structure to support GtkTextViews in GTK+
 * 2.6.
 *
 * Revision 1.7  2005/01/22 15:20:56  mjhammel
 * Removed registration dialog and all references to it.
 *
 * Revision 1.6  2004/12/01 17:02:50  mjhammel
 * Bug #3:  Added support for changing Pilot port from UI.
 * Also, added dependency check on XNotesPlus.h for all srcgtk-d .c files to
 * Imakefile.
 *
 * Revision 1.5  2004/11/30 22:42:49  mjhammel
 * Bug #8: Changed c_utils.c:XPHelp() to expected a URI and pass it directly
 * (as is) to the web browser, removing the addition of the local help
 * directories.  Changed the call to XPHelp to pass in the web url.
 *
 * Revision 1.4  2004/11/16 21:51:36  mjhammel
 * Category editing is now complete for Todos.
 * catedit.c complete for generic use by other Pilot managers.
 *
 * Revision 1.3  2004/11/15 23:53:12  mjhammel
 * First working version of category editor.
 *
 * Revision 1.2  2004/11/15 20:28:55  mjhammel
 * Added support for menus in generic shells (generic.c).
 * Changed to menus from button bar in Todo Manager.
 * Added first pass at Category Edit dialog.
 *
 * Revision 1.1.1.1  2004/10/11 17:35:06  mjhammel
 * Initial import
 *
 * Revision 1.18  2004/02/28 05:27:13  mjhammel
 * Change to opening usersguide.html as opening help page instead of
 * xnotes.html
 *
 * Revision 1.17  2004/02/26 05:22:50  mjhammel
 * Changed about to use gnome-moz-remote.
 * Fixed crash bug in findnote.c
 * Cleaned out all references to ical.
 * Added default browser config as a backup if gnome-moz-remote isn't found.
 * Fixed packaging so xn-cal is included.
 * Changed "Calendar Tool" to "Calendar Manager"
 * Removed signal(SIGCHLD, SIG_IGN) because gdb says we're calling wait() too.
 * Moved check for registration outside of config file parsing.
 *
 * Revision 1.16  2004/02/23 04:36:00  mjhammel
 * Calendar complete for beta 1.
 * Initial documentation updates for 3.6.
 * Fixed bug in FindText.c - accept button should be "gshell.search", not
 * "gshell.accept".
 *
 * Revision 1.15  2004/02/17 14:25:54  mjhammel
 * Added first pass at alarm handling for appointments.
 *
 * Revision 1.14  2004/02/11 03:59:19  mjhammel
 * Added pixmaps to monthly view of calendar.
 * Fixed today display in calendar to show all entries (but more fixes are
 * needed).
 * Added alarm handling to calendar.
 * Added new entry to calendar and made new and edited entries get saved
 * immediately.
 * Fixed much of the repeat handling in the calendar UI.
 *
 * Revision 1.13  2004/02/06 04:01:26  mjhammel
 * New calendar icon.  Updated postal icon.
 * Added toggle button handling to calendar entry edit dialog.
 *
 * Revision 1.12  2004/02/04 04:55:27  mjhammel
 * Updated theme to something not so ugly.
 * Added extra components to Appointment Edit dialog.
 *
 * Revision 1.11  2004/02/01 17:09:17  mjhammel
 * Fixed Todos so current entry updates are reflected immediately in the CList.
 * Appointments Editor now correctly handles editing existing entry vs. new
 * entry.
 *
 * Revision 1.10  2004/01/28 14:16:03  mjhammel
 * Updates to initial calendar code.
 *
 * Revision 1.9  2004/01/23 04:22:41  mjhammel
 * Added WriteAppt and FreeAppt to c_pilot.c
 * Added appointment related defines to XNotesplus.h
 * Added appointment prototypes to prototypes.h
 * Added PopulateCalendar() stub to appointments.c
 * Fixed bug in todos that caused crash when todo entry was deleted.
 *
 * Revision 1.8  2004/01/19 03:26:00  mjhammel
 * XPPilotParseAppointment() for c_pilot.c added and tested.
 *
 * Revision 1.7  2004/01/16 14:54:13  mjhammel
 * Adding Appointment file parsing to c_pilot.c.
 *
 * Revision 1.6  2002/04/07 20:37:24  mjhammel
 * Appointments (ical replacement) updates.
 *
 * Revision 1.5  2002/04/05 05:36:07  mjhammel
 * Appointments feature updates.  Still a long ways to go...
 *
 * Revision 1.4  2002/04/05 00:42:40  mjhammel
 * Added Cancel button to Pilot HotSync dialog (plus some other minor updates).
 *
 * Revision 1.3  2002/02/19 13:40:23  mjhammel
 * Removed app_res.tmp_dir
 *
 * Revision 1.2  2002/02/18 21:49:15  mjhammel
 * First pass at online help
 *
 * Revision 1.1.1.1  2002/01/10 18:37:59  mjhammel
 * Initial checkin
 *
 *
 *========================================================================*/
#ifndef XP_H
#define XP_H

#ifdef DO_PSPELL
#include <pspell/pspell.h>
#endif

#include <time.h>

/*
 * Default values.
 */
#define DefaultBufSize			1024
#define DefaultNameWidth		10
#define DefaultAnchorOffset	15
#define DefaultNoteDir			".xnotesplus"
#define DefaultProjectFile		"xnprojects-gtk"
#define DefaultXPMDir			"xpm-d"
#define DefaultPilotDB			"xnaddress"
#define DefaultAddrDir			"addresses"
#define DefaultPrintCmd			"lpr %s"
#define DefaultEmailCmd			"mail -s\"%s\" %s"
#define DefaultEmailAddr		""
#define DefaultCalendarCmd		"cal"
#define DefaultShCmd				"/bin/sh"
/*
#define DefaultAudioCmd			"sox %s -t .au -v %d /dev/audio"
*/
#define DefaultAudioCmd			"play -v %d -d /dev/audio %s"
#define DefaultAudioCmdString	"play -v \%d -d /dev/audio \%s"
#define DefaultAudioDir			"audio"
#define DefaultRGBFile			"/usr/X11R6/lib/rgb.txt"
#define DefaultPilotDir			"pilot"
#define DefaultInterval			(60*60)
#define DefaultPlaidWidth		64
#define DefaultPlaidHeight		64
#define DefaultListWidth		64
#define DefaultListHeight		64
#define DefaultMaxNotes			255
#define DefaultConfigFile		"XNotesPlus.cfg"
#define DefaultGtkRC				"XNotesPlus.rc"
#define DefaultIdFile			"id"
#define DefaultPTodoFile		"xntodos"
#define DefaultPApptFile		"xnappt"
#define DefaultNenscript		"nenscript"
#define DefaultSpellChecker	"aspell"
#define DefaultSpellCheckFile	".spellcheck"
#define DefaultPrintFile		".printfile"
#define DefaultTmpFile			".tmpfile"
#define DefaultBrowserCmd		"netscape"
#define DefaultHelpDir			"docs-d/html"
/*
#define DefaultHelpTop			"usersguide.html"
*/
#define DefaultHelpTop			"http://www.ximba.org/xnotes/usersguide.html"

/* 
 * Pilot-link and Syncal program names
 * These aren't configurable (they're hard coded for now).
 */
#define DefaultPilotSync		"xn-xfer"
#define DefaultPilotAddr		"xn-addresses"
#define DefaultPilotMemos		"xn-memos"
#define DefaultPilotTodos		"xn-todos"
#define DefaultIcalCmd		   "xn-cal"

#define XP_ALARM_ON_XPM			"alarmon.xpm"
#define XP_ALARM_OFF_XPM		"alarmoff.xpm"
#define XP_ANCHOR_XPM			"anchoron.xpm"
#define XP_ANCHOR_OFF_XPM		"anchoroff.xpm"
#define XP_BLANK_XPM				"blank.xpm"
#define XP_PLAID_XPM				"xnotes.xpm"
#define XP_MSG_XPM				"msg.xpm"
#define XP_INFO_XPM				"info.xpm"
#define XP_ERROR_XPM				"error.xpm"
#define XP_FILE_XPM				"file.xpm"
#define XP_NOTES_XPM				"notes.xpm"
#define XP_STATUS_XPM			"status.xpm"
#define XP_ENVELOPE_XPM			"postal.xpm"
#define XP_PILOT_XPM				"pilot.xpm"
#define XP_ADDR_MGR_XPM			"addr-mgr.xpm"
#define XP_BUTTON_1_XPM			"button-1.xpm"
#define XP_MENU_BAR_XPM			"menu-bar.xpm"
#define XP_CLEAR_XPM				"clear.xpm"
#define XP_GM_LOGO_XPM			"gm-logo.xpm"
#define XP_BG_1_XPM				"bg-1.xpm"
#define XP_CALENDAR_XPM			"calendar.xpm"
#define XP_CAL_MORNING_XPM		"cal-morning.xpm"
#define XP_CAL_NOON_XPM			"cal-noon.xpm"
#define XP_CAL_NIGHT_XPM		"cal-night.xpm"

/*
 * Post-It Note sizes.
 */
#define StickyNote_1p5x2	0
#define StickyNote_2x3		1
#define StickyNote_3x3		2
#define StickyNote_3x4		3
#define StickyNote_3x5		4
#define StickyNote_4x6		5

/*
 * Post-It Note file information.
 */
#define StickyNoteMagic			"%!<postitnote>"
#define StickyNoteMagic_v2		"%%!!<postitnote>"
#define StickyNoteMagic_v3		"%%!!<xpstickynote.v3>"
#define StickyProjMagic_v3		"%%!!<xpproj.v3>"
#define StickyNoteFname			"note"
#define StickyEnvelopeFname	"envelopes"
#define StickyNoteTodoMagic_v2	"%%!!<xntodos.v2>"
#define StickyNoteAddrMagic_v2	"%%!!<xnaddress.v2>"

/* 
 * GtkTextBuffer Tags
 */
#define TAG_HILITE_YELLOW		"hilite-yellow"

/*
 * Config file name/value delimeter.
 */
#define XP_DELIMITER			':'

/*
 * Application class.  Also the program name.
 */
#define StickyNoteClass		"XNotesPlus"
#define XP_S_PROG_NAME		StickyNoteClass
#define XP_S_ABOUT_INFO		"\n\nby\nMichael J. Hammel\nmjhammel@graphics-muse.org\nhttp://www.graphics-muse.org\n\nXNotesPlus is open source software."

/*
 * Menu ids - if you modify these, be sure to update the text arrays
 * in notes.c.
 */
#define XP_FILE_SAVE_ID					0
#define XP_FILE_OPEN_ID					1
#define XP_FILE_EXPORT_ID				2
#define XP_FILE_MERGE_ID				3
#define XP_FILE_FIND_ID					4
#define XP_FILE_SPELL_ID				5
#define XP_FILE_PRINT_ID				6
#define XP_FILE_EMAIL_ID				7

#define XP_OPTIONS_HIDE_ID				0
#define XP_OPTIONS_SHADE_ID			1
#define XP_OPTIONS_ERASE_ID			2
#define XP_OPTIONS_DESTROY_ID			3
#define XP_OPTIONS_NAME_ID				4
#define XP_OPTIONS_PROJ_ID				5
#define XP_OPTIONS_TITLE_ID			6
#define XP_OPTIONS_DATE_ID				7
/*
#define XP_OPTIONS_CALENDAR_ID		5
*/

#define XP_ALARM_ON_ID					0
#define XP_ALARM_OFF_ID					1
#define XP_ANCHOR_ON_ID					0
#define XP_ANCHOR_OFF_ID				1



/*========================================================================
 * Text strings - you can tell the historical naming convention changed.
 *=======================================================================*/

#define StickyNoteList				"Hidden Notes" 
#define MergeNoteList				"Available Notes" 
#define NotesErrDialog				"XNotesPlus Error"
#define ApptDialog					"Appointments"
#define NewApptDialog				"Add an Appointment"
#define NotesAlarmDialog			"XNotesPlus Alarm"
#define NotesTimerPrompt			"Alarms Setup"
#define NotesAddrPrompt				"Print Envelopes"
#define AddrListPrompt				"Select an address"
#define AddrMgrDialog				"Address Manager"
#define AddrEditorDialog			"Address Editor"
#define NotesIOPrompt				"File Selection Window"
#define NotesPilotBUPrompt			"Select Pilot Backup Directory"
#define NotesInsertPrompt			"Insert Date"
#define NotesFindPrompt				"Find A Note"
#define NotesEmailPrompt			"Email Note"
#define NotesOptionsMenu			"OptionsMenu"
#define NotesFileMenu				"FileMenu"
#define StickyNoteDialog			"Title for Note"
#define NotesSaveOnExitPrompt		"Save Notes"
#define NotesConfirmDialog			"Confirm"
#define ProjectDialog				"Projects"
#define ProjectNoteDialog			"Change Project"
#define FindTextDialog				"Search"
#define SpellCheckDialog			"Spell Check"
#define PilotDialog					"PalmPilot Interface"
#define PilotPortEditDialog		"Edit Pilot Port"
#define RenameDirDialog				"Rename Directory"
#define AboutDialog					"About XNotesPlus"
#define TodoListDialog				"Todo Manager"
#define EditNoteDialog				"Todo Note"
#define CalendarDialog				"Calendar"
#define PilotFileList				"Pilot DB Listing"
#define CategoryEditDialog			"Edit Categories"

#define XP_ERROR_TITLE				"XNotes Error"
#define XP_MSG_TITLE					"XNotes Message"
#define XP_INFO_TITLE				"XNotes Info"
#define XP_CONFIRM_TITLE			"XNotes Confirmation"

#define XP_FILE_LABEL				"File"
#define XP_NOTES_LABEL				"Notes"
#define XP_FILE_SAVE					"Save..."
#define XP_FILE_OPEN					"Open..."
#define XP_FILE_EXPORT				"Export..."
#define XP_FILE_MERGE				"Merge..."
#define XP_FILE_FIND					"Find..."
#define XP_FILE_SPELL				"Spell Check..."
#define XP_FILE_PRINT				"Print"
#define XP_FILE_EMAIL				"Email..."
#define XP_OPTIONS_HIDE				"Hide"
#define XP_OPTIONS_SHADE			"Shade"
#define XP_OPTIONS_ERASE			"Erase"
#define XP_OPTIONS_DESTROY			"Destroy"
#define XP_OPTIONS_NAME				"Name..."
#define XP_OPTIONS_PROJECT			"Project..."
#define XP_OPTIONS_TITLE			"Toggle Title"
#define XP_OPTIONS_ANCHOR			"Anchor"
#define XP_OPTIONS_NOANCHOR		"Unanchor"
#define XP_OPTIONS_ALARM			"Set Alarm..."
#define XP_OPTIONS_NOALARM			"Unset Alarm"
#define XP_OPTIONS_CALENDAR		"Show Calendar"
#define XP_OPTIONS_DATE				"Insert Date"
#define XP_ALARM_ON					"Set Alarm"
#define XP_ALARM_OFF					"Disable Alarm"
#define XP_ANCHOR_ON					"Set Anchor"
#define XP_ANCHOR_OFF				"Disable Anchor"

#define XP_S_CONFIRM					"Confirm"
#define XP_S_ACCEPT					"Accept"
#define XP_S_CANCEL					"Cancel"
#define XP_S_OK						"OK"
#define XP_S_TOGGLE					"Toggle"
#define XP_S_CLOSE					"Close"
#define XP_S_SAVE						"Save"
#define XP_S_LOAD						"Load"
#define XP_S_PRINT					"Print"
#define XP_S_PRINT_DISPLAYED		"Print Displayed"
#define XP_S_PRINT_SELECTED		"Print Selected"
#define XP_S_YES						"Yes"
#define XP_S_NO						"No"
#define XP_S_NEXT						"Next"
#define XP_S_PREV						"Previous"
#define XP_S_HOME						"Home"
#define XP_S_DONE						"Done"
#define XP_S_START					"Start"
#define XP_S_STOP						"Stop"
#define XP_S_SUGGESTIONS			"Suggested Replacements"
#define XP_S_CURRENT_WORD			"Current Word"
#define XP_S_MODIFY_WORD			"Modify Word"
#define XP_S_SKIP_WORD				"Skip Word"
#define XP_S_LEARN_WORD				"Learn Word"
#define XP_S_SET_TIME				"Set Time"
#define XP_S_CURRENT_TIME			"Last Setting"
#define XP_S_CONVERT					"To XNote"
#define XP_S_SET_AUDIO				"Select Audio To Play"
#define XP_S_SET_AUDIO_VOL			"Volume"
#define XP_S_NO_AUDIO				"NONE"
#define XP_S_NO_PROJECT				"NONE"
#define XP_S_FROM_ADDR				"From:"
#define XP_S_TO_ADDR					"To:"
#define XP_S_PT_SIZE					"Pt. Size"
#define XP_S_ENVELOPES				"Envelopes"
#define XP_S_ENV_TYPE				"Envelope Type"
#define XP_S_PRINTER					"Printer Command"
#define XP_S_PRINTER_NAME			"Name of printer to use"
#define XP_S_IMPORT					"Import"
#define XP_S_EXPORT					"Export"
#define XP_S_ERASE					"Erase"
#define XP_S_FETCH_MEMOS			"Fetch"
#define XP_S_FETCH					"Pilot->XNotes"
#define XP_S_SYNC						"XNotes->Pilot"
#define XP_S_NEW_ENTRY				"New Entry"
#define XP_S_DELETE_ENTRY			"Delete Entry"
#define XP_S_ADD_ENTRY				"Add Entry"
#define XP_S_ADD_NOTE				"Add Note"
#define XP_S_EDIT_ENTRY				"Edit Entry"
#define XP_S_SORT_REVERSE			"Reverse Sort Order"
#define XP_S_NO_DATE					"No Date"
#define XP_S_LOCAL					"Local"
#define XP_S_GMT						"GMT"
#define XP_S_FULL						"Full"
#define XP_S_ABBR						"Abbr"
#define XP_S_SET_DATE				"Set Date"
#define XP_S_ALL_ADDR				"All Addresses"
#define XP_S_PROCESS					"Process"
#define XP_S_CASE						"Case Sensitive"
#define XP_S_DIRECTION				"Search Backwards"
#define XP_S_SEARCH_PROMPT			"Enter text to search for:"
#define XP_S_SPELLCHECK_PROMPT	"Spell Checking..."
#define XP_S_NOT_FOUND				"No further occurances of string\nin that direction."
#define XP_S_NO_DATE					"No Date"
#define XP_S_FILTER_CATEGORY		"Filter on Category"
#define XP_S_NONE						"None"
#define XP_S_DAILY					"Daily"
#define XP_S_WEEKLY					"Weekly"
#define XP_S_MONTHLY					"Monthly"
#define XP_S_YEARLY					"Yearly"
#define XP_S_FOREVER					"Forever"
#define XP_S_STARTSTOP				"Start / Stop Times"
#define XP_S_START_TIME				"Start Time"
#define XP_S_STOP_TIME				"Stop Times"
#define XP_S_TODO_TITLE				"Todo Title:"
#define XP_S_STATUS_FIELD			"Status:"
#define XP_S_PRIORITY_FIELD		"Pri:"
#define XP_S_NOTE_FIELD				"Note:"
#define XP_S_DUE_DATE_FIELD		"Due Date:"
#define XP_S_CATEGORY_FIELD		"Category:"
#define XP_S_EDIT_CATEGORIES		"Edit Categories"
#define XP_S_EDIT_PILOTPORT		"Edit PILOTPORT"
#define XP_S_PILOTPORT_LABEL		"Device port: "

#define XP_S_PROJECT					"Background color..."

/* These 4 are used for Generic Shell menus */
#define XP_S_GFILE					"File"
#define XP_S_GEDIT					"Edit"
#define XP_S_GOPTIONS				"Options"
#define XP_S_GHELP					"Help"

#define XP_S_TODO_1					"Status"
#define XP_S_TODO_2					"Pri"
#define XP_S_TODO_3					"Title"
#define XP_S_TODO_4					"Notes"
#define XP_S_TODO_5					"Due Date"
#define XP_S_TODO_6					"Category"

#define XP_S_PILOT_ADDR				"Pilot Addresses"
#define XP_S_PILOT_TODOS			"Pilot Todo List"
#define XP_S_PILOT_ICAL				"Calendar Sync"
#define XP_S_PILOT_MEMOS			"Pilot Memos"
#define XP_S_PILOT_SYNC				"Pilot Sync"
#define XP_S_PILOT_MODE				"Mode"
#define XP_S_PILOT_START			"Start Transfer"
#define XP_S_PILOT_REMOVE			"Remove Dir"
#define XP_S_PILOT_RENAME			"Rename Dir"
#define XP_S_PILOT_CATEGORIES		"Categories"
#define XP_S_PILOT_FILTER			"Filter on ..."
#define XP_S_PILOT_FILTER_TEXT	"Filter String"
#define XP_S_PILOT_ADDR_DETAILS	"Details"
#define XP_S_PILOT_USEDATE			"Today"
#define XP_S_FILE_NAME				"Filename:"

#define XP_S_ADDR_EDIT_PG_1		"Name/Address"
#define XP_S_ADDR_EDIT_PG_2		"Phone/Email"
#define XP_S_ADDR_EDIT_PG_3		"Custom Fields"

#define XP_S_LAST_NAME				"Last Name:"
#define XP_S_FIRST_NAME				"First Name:"
#define XP_S_TITLE					"Title:"
#define XP_S_COMPANY					"Company:"
#define XP_S_ADDRESS					"Address:"
#define XP_S_CITY						"City:"
#define XP_S_STATE					"State:"
#define XP_S_ZIPCODE					"Zip Code:"
#define XP_S_COUNTRY					"Country:"
#define XP_S_CUSTOM1					"Custom 1:"
#define XP_S_CUSTOM2					"Custom 2:"
#define XP_S_CUSTOM3					"Custom 3:"
#define XP_S_CUSTOM4					"Custom 4:"
#define XP_S_NOTE_TEXT				"Note:"
#define XP_S_CATEGORY_NAME			"Category:"
#define XP_S_CAT_UNFILED			"Unfiled"
#define XP_S_UNKNOWN_PERSON		"Unknown person?"

#define XP_S_SUN						"Sun"
#define XP_S_MON						"Mon"
#define XP_S_TUE						"Tue"
#define XP_S_WED						"Wed"
#define XP_S_THU						"Thu"
#define XP_S_FRI						"Fri"
#define XP_S_SAT						"Sat"

#define XP_S_CAT_DELETE				"Delete Category"
#define XP_S_CAT_MODIFY				"Modify Category"
#define XP_S_CAT_ADD					"Add Category"

#define XP_S_APPT_SUMMARY			"Appointment Summary for "
#define XP_S_APPT_WEEK_SUMMARY	"Appointment Summary for Week of "
#define XP_S_APPT_MONTH_SUMMARY	"Appointment Summary for Month of "
#define XP_S_EVENT_SUMMARY			"Event Summary"
#define XP_S_EVENT_NOTES			"Event Notes"
#define XP_S_PERIODIC_REPEAT		"Periodic Repeat "
#define XP_S_REPEAT_UNTIL			"Repeat ..."
#define XP_S_APPT_ALARM_ON			"On"
#define XP_S_APPT_ALARM_OFF		"Off"
#define XP_S_APPT_ALARM_EVENT		"Appointment Reminder:"
#define XP_S_APPT_NOTIFY			"Notify within"
#define XP_S_REPEAT_WEEKDAYS		"Repeat on each ..."
#define XP_S_UNTIL					"Until"
#define XP_S_FOREVER					"Forever"
#define XP_S_CAL_ITEM				"Calendar Item Summary"

#define XP_S_NONETSCAPE				"Can't find Netscape.  Try visiting\nhttp://www.graphics-muse.org/xnotes/xnotes.html."
#define XP_S_REGISTER_CMD1 		"http://www.graphics-muse.org/xnotes/xnotes.html#payments"
#define XP_S_REGISTER_CMD2			"netscape http://www.graphics-muse.org/xnotes/xnotes.html#payments > /dev/null 2>&1 &"
#define XP_S_REGISTER_OK 		   "You've already attempted registration.\nNo need to try again!"

#define XP_S_PILOT_HOTSYNC			"Press the HotSync button on the Pilot's cradle now.\nThen click the Accept button to start the transfer."

#define XP_S_UNKNOWN_CAT			"You need to add the \"xnotes\" category to the Pilot\nbefore trying to upload an XNote to it."

#define XP_S_NO_ADDRS				"No matching entries."
#define XP_S_ENV_ERR1				\
"Problems doing cleanup after printing envelope.\n%s could not be unlinked.\n"


#define XP_S_DESTROY_CONFIRM		"Do you really want\nto destroy this note?"
#define XP_S_NO_NOTES				"You have no notes."
#define XP_S_NO_HIDDEN_NOTES		"There are no hidden notes."
#define XP_S_NO_NOTES_TO_RAISE	"There are no notes to raise."
#define XP_S_NO_NOTES_TO_HIDE		"There are no notes to hide."
#define XP_S_NO_NOTES_TO_UNHIDE	"There are no notes to unhide."
#define XP_S_NO_NOTES_TO_LOWER	"There are no notes to lower."
#define XP_S_NO_ANCHORED_NOTES	"There are no anchored notes."
#define XP_S_FILE_EXIST				"File already exists.  Overwrite?"
#define XP_S_NOTE_PTR_MISSING		"Can't fine associated note structure!"
#define XP_S_EXPIRED_1				"The alarm has expired for the Note\n"
#define XP_S_EXPIRED_2				"with the following name:\n"
#define XP_S_CANT_RUN_CMD			"Couldn't run %s: return code = %d" 
#define XP_S_CANT_RUN_CMD2			"Couldn't run %s: return code = unknown" 
#define XP_S_EMAIL					"Enter the email address of the intended recipient"
#define XP_S_EMAIL_NONAME			"Use the Address Manager to find an address."
#define XP_S_NO_TEXT_TO_PRINT		"No text in note to print!"
#define XP_S_NOTE_PRINTED			"The note has been sent to the printer!"
#define XP_S_ADDR_PRINTED			"The address list has been sent to the printer!"
#define XP_S_TODO_PRINTED			"The selected Todo item has\nbeen sent to the printer!"
#define XP_S_TODOS_PRINTED			"The displayed Todo items have\nbeen sent to the printer!"
#define XP_S_NO_TEXT_TO_SPELLCHECK		"There is no text to spell check!"
#define XP_S_NO_MISSSPELLED		"There are no misspelled words."
#define XP_S_NO_MORE_MISSSPELLED	"There are no more misspelled words."
#define XP_S_TEMP_OPEN_FAIL		"Can't open tempoary file for\nwriting: %s"
#define XP_S_DEFAULT_NOTE_TITLE	"Untitled Note"
#define XP_S_NO_CONFIG_FILE		"%s: Can't find config file %s.\n"
#define XP_S_SAVE_NOTES				"Save Changed Notes?  "
#define XP_S_FIND_FAIL				"Can't find string: "
#define XP_S_NO_RGB					"Could not read rgb.txt file!"

#define XP_S_MSG_BAD_VISUAL		"Unsupported visual.  Can't run with < 256 colors."

#define XP_S_MSG_LIMITED_VISUAL	"You're visual has limited color capabilities.\nYou may encounter problems with colors"

#define XP_S_CANT_CONV_COLOR		"Sorry, but that color doesn't\nseem to be available for some reason."

#define XP_S_CANT_FIND_PROJ		"Can't find that project!"
#define XP_S_SAMPLE_NOTE			"Sample Note Text"

#define XP_S_DISABLE_CMDS			"The following features have been disabled because either the \nconfigured external application for them could not be \nlocated in your path or a needed data file could not be found:\n\n"

#define XP_S_DISABLE_PRINT			"Printing (%s)\n"
#define XP_S_DISABLE_CAL			"Calendar Insert (%s)\n"
#define XP_S_DISABLE_NENSCRIPT	"Nenscript (for envelope printing) (%s)\n"
#define XP_S_DISABLE_SPELLCHECK	"Spell check (%s)\n"
#define XP_S_DISABLE_BROWSER		"Help browser (%s)\n"
#define XP_S_DISABLE_EMAIL			"Email Notes (%s)\n"
#define XP_S_DISABLE_AUDIO			"Audio alarms (%s)\n"
#define XP_S_DISABLE_PROJECTS		"Note Projects\n"
#define XP_S_DISABLE_ICAL			"Calendar Manager(%s)\n"
#define XP_S_DISABLE_SYNCAL		"Calendar Sync with Pilot (%s)\n(Calendar sync with Pilot will be disabled)\n"
#define XP_S_LIST_EMPTY				"You must select items from the list first."

#define XP_S_DISABLE_PILOT_PORT	"\nThe environment variable PILOTPORT must be set in order to\nuse the Pilot Tool feature.  You should set this to the\nserial port (/dev/cua, for example) to which the Pilot\ncradle is connected.\n"

#define XP_S_DISABLE_PILOT_PORT2	"\nThe environment variable PILOTPORT specifies a device\nthat can't be opened.  Access to the Pilot tools has\n been disabled.\n\n"

#define XP_S_DISABLE_PILOT_RATE	"\nThe environment variable PILOTRATE should be set in order to\nuse the Pilot Tool feature.  You should set this to any high\nbaud rate, such as 57600.\n"

#define XP_S_INSTALL_ERR_1			"Unable to open"
#define XP_S_INSTALL_ERR_2			"failed"
#define XP_S_DELETE_ERR				"Failed"
#define XP_S_FETCH_ERR				"Unable to locate"
#define XP_S_INSTALL_ERR_MSG_1	"%s either doesn't exist or\nis not a Pilot prc/pdb file"
#define XP_S_INSTALL_ERR_MSG_2	"The Pilot reported a generic problem installing\n- %s -\nIt may not have enough memory for this file, but\nyou might want to try installing it again to be sure."
#define XP_S_DELETE_ERR_MSG		"The requested database\n- %s -\ndoesn't exist on the Pilot"
#define XP_S_FETCH_ERR_MSG			XP_S_DELETE_ERR_MSG

#define XP_S_DISABLE_PILOT_SYNC	"Pilot Sync (%s)\n"
#define XP_S_DISABLE_PILOT_ADDR	"Pilot Addresses (%s)\n"
#define XP_S_DISABLE_PILOT_MEMOS	"Pilot Memos (%s)\n"
#define XP_S_DISABLE_PILOT_TODO	"Pilot Todos (%s)\n"
#define XP_S_DISABLE_PILOT_ICAL	"Pilot Calendar (%s)\n"
#define XP_S_COLOR_CHOICES			"Colors"
#define XP_S_PROJ_CHOICES			"Projects"
#define XP_S_PROJ_UPD				"Project has been updated."
#define XP_S_DELETE_PROMPT			"Delete directory %s?"

#define XP_S_PILOT_MENU_BU			"Backup all files from Pilot"
#define XP_S_PILOT_MENU_RESTORE	"Restore existing backup"
#define XP_S_PILOT_MENU_SYNC		"Sync backups with Pilot"
#define XP_S_PILOT_MENU_UPDATE	"Update backups from Pilot"
#define XP_S_PILOT_MENU_INSTALL	"Install file(s) to Pilot"
#define XP_S_PILOT_MENU_FETCH		"Fetch database from Pilot"
#define XP_S_PILOT_MENU_DELETE	"Delete database from Pilot"
#define XP_S_PILOT_MENU_LIST		"List all databases on Pilot"

#define XP_S_PILOT_NOT_A_DIR		"%s exists and is not a directory!"
#define XP_S_PILOT_DELETE_FILE	"Please specify the name of the database to delete."
#define XP_S_PILOT_FETCH_FILE		"Please specify the name of the database to fetch."
#define XP_S_PILOT_FETCH_DIR		"Please specify the name of the\ndirectory in which to save %s."
#define XP_S_PILOT_INSTALL_FILE	"%s does not exist or cannot be read."
#define XP_S_PILOT_INSTALL_FILE2	"Please specify the name of the database to install."
#define XP_S_PILOT_IMEMO_OK		"Memos uploaded to Pilot successfully."
#define XP_S_PILOT_MEMO_OK			"Memos downloaded from Pilot successfully."
#define XP_S_PILOT_ICAL1_OK		"Calendar successfully\nsyncronized with the Pilot."
#define XP_S_PILOT_SYNC_OK			"Pilot backed up/synced/restored/updated successfully."
#define XP_S_PILOT_INSTALL_OK		"File installed successfully."
#define XP_S_PILOT_DELETE_OK		"File deleted successfully."
#define XP_S_PILOT_FETCH_OK		"Pilot fetch succeeded."
#define XP_S_PILOT_LIST_OK			"Pilot DB list succeeded."
#define XP_S_PILOT_ADDR_OK			"Pilot Address database\nretrieved successfully."
#define XP_S_PILOT_ADDR_S_OK		"Pilot Address database\nuploaded successfully."
#define XP_S_PILOT_TODO_SYNC		"Todos successfully synced to Pilot."
#define XP_S_PILOT_TODO_FETCH		"Todos successfully retrieved from Pilot."
#define XP_S_PILOT_ICAL_FETCH		"Calendar successfully retrieved from Pilot."
#define XP_S_PILOT_ICAL_SYNC		"Calendar successfully synced to Pilot."
#define XP_S_PTITLE_MEMO			"# Temporary script to download memos from a PalmPilot.\n"
#define XP_S_PTITLE_IMEMO			"# Temporary script to install notes into Memos database on a PalmPilot.\n"
#define XP_S_PTITLE_ICAL1			"# Temporary script to syncrhonize the Ical calendar with your PalmPilot.\n"
#define XP_S_PTITLE_ICAL_SYNC		"# Temporary script to install appointments with your PalmPilot.\n"
#define XP_S_PTITLE_ICAL_FETCH	"# Temporary script to synchronize appointments with your PalmPilot.\n"
#define XP_S_PTITLE_ADDR			"# Temporary script to retrieve Address database from a PalmPilot.\n"
#define XP_S_PTITLE_ADDR_S			"# Temporary script to upload Address database to a PalmPilot.\n"
#define XP_S_PTITLE_SYNC			"# Temporary script to backup/restory/sync/update a PalmPilot.\n"
#define XP_S_PTITLE_INSTALL		"# Temporary script to install data to a PalmPilot.\n"
#define XP_S_PTITLE_DELETE			"# Temporary script to delete data from a PalmPilot.\n"
#define XP_S_PTITLE_FETCH			"# Temporary script to fetch data from a PalmPilot.\n"
#define XP_S_PTITLE_LIST			"# Temporary script to list data on a PalmPilot.\n"
#define XP_S_PTITLE_TODO			"# Temporary script to process PalmPilot Todos.\n"

#define XP_S_PATH_INVALID			"The directory path must be fully qualified."
#define XP_S_RENAME_FAIL			"Failed to rename directory %s\nto %s.\nerrno=%d"

#define XP_S_LOCDB_FAIL				"Failed to read local Address databases."
#define XP_S_LOCTODO_FAIL			"Failed to read local Todo database."
#define XP_S_LOCAPPT_FAIL			"Failed to read local Appointment database."

#define XP_S_ENABLE_TIPS			"Enable Tool Tips"
#define XP_S_DISABLE_TIPS			"Disable Tool Tips"

#define XP_S_PRT_MISSING			"You must provide a printer name to print envelopes."
#define XP_S_PRT_FROM				"You must provide a \"From\" address\nto print envelopes."
#define XP_S_PRT_TO					"You must provide a \"To\" address\nto print envelopes."
#define XP_S_CANT_FIND_XPM			"xnotes+: Can't find XPM file %s.  Exiting.\n"

#define XP_S_REPEAT_TEXT			"Repeat"
#define XP_S_MONTH					"Month"
#define XP_S_DAY						"Day"
#define XP_S_DAYS						"Days"
#define XP_S_HOUR						"Hour"
#define XP_S_MIN						"Min"

#define XP_S_CASE_SENSITIVE		"Case Sensitive"
#define XP_S_CASE_INSENSITIVE		"Case Insensitive"

#define XP_S_PRINT_ADDR				\
"Select one or more addresses from the displayed list,\n\
then click the Accept button. You can choose a Category\n\
and use the Filter options before making your selections.\n\
\n\
A right mouse click selects a single address.\n\
Shift-click selects a range of addresses.\n\
Ctrl-click adds a single address to current selections.\n\
Ctrl-Shift-click adds a range to the current selections.\n\
"

#define XP_S_PRINT_SEPARATOR		\
"-----------------------------------------------------------------------------\n"

#define XP_S_PRINT_TODO_HDR		\
"XNotesPlus %s\nTodo Manager\n\
\n\
-----------------------------------------------------------------------------\n\
\n"

#define XP_S_PRINT_ADDR_HDR		\
"XNotesPlus %s\nAddress Manager\n\
\n\
-----------------------------------------------------------------------------\n\
\n"

#define XP_S_NO_DEBUGGING			\
"Invalid option.  XNotesPlus has not been compiled with debugging turned on.\n"


/*
 * Help Message
 */
#define USAGE \
"\n\
xnotes+ [ -c | --sb | --sv | --ns | --na | --help/-?/-h | --bs bufsize \n\
         | --notedir notedir | --interval seconds | --nw pixels \n\
         | --ao pixels | --printcmd cmd | --emailcmd cmd \n\
         | --emailaddr address | --calendarcmd cmd \n\
         | --spellchecker cmd | --browser cmd | \n\
         | --homedir path | --xpmdir dir | --audiocmd cmd | --audiodir dir \n\
         | --noaudio | --addrdir dir | --pilotdir dir | --rgbfile path \n\
         | --defaults | --install | --version ]\n\
where\n\
    -c                   turns on compatibility mode\n\
    --sb                 turns on scrollbars for all notes\n\
    --sv                 enables save-on-exit\n\
    --ns                 disables the auto save feature\n\
    --na                 disables the alarm feature\n\
    --nn                 disables the dialog showing disabled features\n\
    --help | -? | -h     prints this help message\n\
    --bs bufsize         sets the buffer size for all notes\n\
    --notedir notedir    specifies the directory to load and save notes\n\
    --interval minutes   specifies the auto-save timeout value\n\
    --nw pixels          width, in pixels, of a single character\n\
    --ao offset          offset, in pixels, for X,Y coords of cascaded notes\n\
    --printcmd cmd       print command (use %%s for filename)\n\
    --emailcmd cmd       command to use to send email (use %%s for filename)\n\
    --emailaddr address  default email address\n\
    --calendarcmd cmd    calendar command\n\
    --spellchecker cmd   ispell/aspell compliant program \n\
                         (fully qualified if necessary) \n\
    --browser cmd        browser used to display help files\n\
                         (fully qualified if necessary) \n\
    --homedir path       default home directory (used by file selection \n\
                         window\n\
    --xmpdir dir         where XNotesPlus bitmaps can be found\n\
    --audiocmd cmd       command to run audio files (use %%s for audio file)\n\
    --audiodir dir       where audio files are stored\n\
    --noaudio            disable audio for alarms\n\
    --addrdir dir        where address files are stored\n\
    --rgbfile path       fully qualified path to rbg.txt file\n\
    --pilotdir           directory to save PalmPilot backups to\n\
\n\
    --defaults           show configured defaults for all parameters\n\
    --notips             don't show tool tips\n\
    --install            install a private colormap (for low color displays)\n\
    --version            print the current version number\n\
\n\
"

/*========================================================================
 * Keyboard Accelerators
 * The first set are what gets displayed in the menus.
 * The second set are the Motif bindings.
 *=======================================================================*/
/* Anchor/Alarm Toggles */
#define XP_ALARM_ON_ACCEL_TEXT				"Alt-t"
#define XP_ALARM_OFF_ACCEL_TEXT				"     "
#define XP_ANCHOR_ON_ACCEL_TEXT				"Alt-a"
#define XP_ANCHOR_OFF_ACCEL_TEXT				"     "

/* Notes (aka Options) menu */
#define XP_OPTIONS_HIDE_ACCEL_TEXT			"Alt-h"
#define XP_OPTIONS_SHADE_ACCEL_TEXT			"Alt-S"
#define XP_OPTIONS_ERASE_ACCEL_TEXT			"Alt-e"
#define XP_OPTIONS_DESTROY_ACCEL_TEXT		"Alt-d"
#define XP_OPTIONS_NAME_ACCEL_TEXT			"Alt-n"
#define XP_OPTIONS_PROJECT_ACCEL_TEXT		"Alt-P"
#define XP_OPTIONS_TITLE_ACCEL_TEXT			"Alt-T"
#define XP_OPTIONS_CALENDAR_ACCEL_TEXT		"Alt-c"
#define XP_OPTIONS_DATE_ACCEL_TEXT			"Alt-D"

/* File Menu */
#define XP_FILE_SAVE_ACCEL_TEXT				"Alt-s"
#define XP_FILE_OPEN_ACCEL_TEXT				"Alt-o"
#define XP_FILE_EXPORT_ACCEL_TEXT			"Alt-x"
#define XP_FILE_FIND_ACCEL_TEXT				"Alt-f"
#define XP_FILE_PRINT_ACCEL_TEXT				"Alt-p"
#define XP_FILE_EMAIL_ACCEL_TEXT				"Alt-m"

/* General options */
#define XP_FILE_ADDR_MGR_ACCEL_TEXT			"Alt-A"
#define XP_FILE_ENVELOPE_ACCEL_TEXT			"Alt-E"
#define XP_FILE_QUIT_ACCEL_TEXT				"Alt-q"

/*========================================================================
 * Configuration file tokens
 *=======================================================================*/
#define XP_CFG_HOME						"HOMEDIR"
#define XP_CFG_NOTEDIR					"NOTEDIR"
#define XP_CFG_TMPDIR					"TMPDIR"
#define XP_CFG_XPMDIR					"XPMDIR"
#define XP_CFG_AUDIODIR					"AUDIODIR"
#define XP_CFG_PILOTDIR					"PILOTDIR"
#define XP_CFG_ADDRDIR					"ADDRDIR"

#define XP_CFG_NOAUDIO					"NOAUDIO"
#define XP_CFG_AUTOSAVE_INTERVAL		"SAVEINTERVAL"
#define XP_CFG_SAVEEXIT					"SAVEEXIT"
#define XP_CFG_AUTOSAVE					"AUTOSAVE"
#define XP_CFG_ALARM						"ALARM"
#define XP_CFG_NOTICE					"NOTICE"
#define XP_CFG_NOSAVE					"NOSAVE"

#define XP_CFG_GTKRC						"GTKRC"
#define XP_CFG_TOOLTIP					"TOOLTIPS"

#define XP_CFG_AUDIO						"AUDIOCMD"
#define XP_CFG_CAL						"CALENDARCMD"
#define XP_CFG_EMAIL						"EMAILCMD"
#define XP_CFG_EMAIL_ADDR				"EMAILADDR"
#define XP_CFG_PRINT						"PRINTCMD"
#define XP_CFG_SPELL_CHECK				"SPELLCMD"
#define XP_CFG_BROWSER					"BROWSER"

/* State types */
#define XP_CFG_ON							"ON"
#define XP_CFG_OFF						"OFF"
#define XP_CFG_YES						"YES"
#define XP_CFG_NO							"NO"

/*
 * Dummy text for Gtk's Address Manager Details dialog.
 */
#define XP_S_DETAILS_DATA	\
"WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW\n\
WWWWWWWWWWWWWWWWWWWWWWWWWW"


/*========================================================================
 * Numeric symbols
 *=======================================================================*/

/*
 * Request for a new note index number.
 */
#define NewIndex				-1

/*
 * Types for the InsertText() and FillList() functions
 */
#define TEXT_TYPE				0
#define FILE_TYPE				1
#define DIR_TYPE				2

/*
 * Types for the CreateIOPrompt() function
 */
#define XNOTES_OPEN_FILE		0
#define XNOTES_EXPORT_FILE		1

/*
 * Just in case.
 */
#ifndef MAXPATHLEN
#define MAXPATHLEN			1024
#endif

/*
 * Maximum number of directory files we can handle
 */
#define XP_MAX_FILES			1024

/*
 * Alarm timeout periods (in seconds, generally).
 */
#define XP_ALARM_PERIOD				60

/*
 * Maximum width (in characters) for a line of an error dialog message.
 */
#define XP_MAX_ERR_TEXT_LENGTH	80

/*
 * Maximum width (in characters) for a line of a confirm dialog message.
 */
#define XP_MAX_CONFIRM_TEXT_LENGTH	80

/*
 * Maximum width in characters for alarm notifications.
 */
#define XP_MAX_ALARM_NOTIFY_LENGTH	80

/*
 * Width and height of the Find a Note list.
 */
#define XP_FIND_WIDTH				250
#define XP_FIND_HEIGHT				250

/*
 * Width and height of the Address list.
 */
#define XP_ADDR_WIDTH				XP_FIND_WIDTH
#define XP_ADDR_HEIGHT				XP_FIND_HEIGHT

/*
 * Width and height of the Project list.
 */
#define XP_PROJ_WIDTH				220
#define XP_PROJ_HEIGHT				100

/*
 * Width and height of audio lists.
 */
#define XP_AUDIO_WIDTH				100
#define XP_AUDIO_HEIGHT				100


/*
 * Width and height of audio lists.
 */
#define XP_TODONOTE_W				265
#define XP_TODONOTE_H				235


/*
 * Buttons to use in generic shell widgets.  There are gaps in here, but
 * thats not important right now.
 */
#define ACCEPT_BUTTON		0x0001   /* accepts input and begins processing */
#define CANCEL_BUTTON		0x0002   /* used to close windows */
#define OK_BUTTON				0x0004   /* displays "OK" instead of "Accept" */
#define OVERWRITE_BUTTON	0x0008   /* overwrites a file */
#define APPEND_BUTTON		0x0010   /* appends to a file */
#define HELP_BUTTON			0x0020   /* opens help window */
#define PRINT_BUTTON			0x0040   /* same as "accept", but displays "Print" */
#define YES_BUTTON			0x0080   /* same as "accept", but displays "Yes" */
#define CLOSE_BUTTON			0x0100   /* same as "Cancel" but w/different text */
#define NO_BUTTON				0x0200   /* same as "Cancel" but w/different text */
#define SEARCH_BUTTON		0x0400   /* same as "accept" but w/different text */
#define ALL_BUTTON			0x0fff   /* never used */
#define XP_GENERIC_MENU		0x8000   /* Use menu bar instaed of button bar */

/* These define menus in a Generic Dialog (generic.c) */
#define XP_GENERIC_MENU1	0   		
#define XP_GENERIC_MENU2	1   		
#define XP_GENERIC_MENU3	2   		
#define XP_GENERIC_MENU4	3   		
 
/* These define Pilot manager types */
#define XP_PM_TODOS_TYPE	1
 
/*
 * Message Window types
 */
#define XP_ERROR_TYPE		0x0001
#define XP_MSG_TYPE			0x0002
#define XP_INFO_TYPE			0x0004
#define XP_CONFIRM_TYPE		0x0008
#define XP_PILOT_TYPE		0x0010
#define XP_MSG_NOCANCEL		0x0100
#define XP_MSG_NOHELP		0x0200
#define XP_MSG_NOOK			0x0400
#define XP_MSG_NOACCEPT		0x0800

/*
 * Pilot types (used by pilot.c:FetchPilot())
 */
#define XP_PILOT_MEMO			0
#define XP_PILOT_INST			1
#define XP_PILOT_ADDR			2
#define XP_PILOT_ADDR_S			3
#define XP_PILOT_SYNC			4
#define XP_PILOT_ICAL_FETCH	5
#define XP_PILOT_ICAL_SYNC		6
#define XP_PILOT_TODO_FETCH	7
#define XP_PILOT_TODO_SYNC		8

/*
 * Pilot Sync frame modes.
 */
#define XP_PILOT_MODE_BU		0
#define XP_PILOT_MODE_RESTORE	1
#define XP_PILOT_MODE_SYNC		2
#define XP_PILOT_MODE_UPDATE	3
#define XP_PILOT_MODE_INSTALL	4
#define XP_PILOT_MODE_FETCH	5
#define XP_PILOT_MODE_DELETE	6
#define XP_PILOT_MODE_LIST		7

/*
 * Project types (for GTK version's calls to XPProject())
 */
#define XP_PROJ_CONFIG		1
#define XP_PROJ_USER			2

/*
 * Tool Tip states
 */
#define XP_TIPS_OFF			0
#define XP_TIPS_ON			1

/*
 * XPConvertCase types
 */
#define XP_LOWER				1
#define XP_UPPER				2

/*
 * Directional types
 */
#define XP_FORWARD			1
#define XP_BACKWARD			2

/*
 * Sort types
 */
#define SORT_BY_LAST			1
#define SORT_BY_FIRST		2
#define SORT_BY_COMPANY		3
#define SORT_BY_CITY			4
#define SORT_BY_CATEGORY	5

/*
 * List data
 */
#define VISIBLE_EMAIL		3
#define NUM_FORMATS			22
#define VISIBLE_FORMATS		15

/*
 * Memo types
 */
#define XP_MEMO_APPEND		1
#define XP_MEMO_REPLACE		2

/*
 * Spell Checker types
 */
#define XP_NO_SUGGESTIONS		0
#define XP_HAS_SUGGESTIONS		1

/*
 * Address Manager Print types
 */
#define XP_ADDR_PRINT			0
#define XP_ADDR_DISPLAY			1

/*
 * pn_type's for StickyNote structure.
 * These define some of the special features of the notes.
 * But so far, these aren't used - future enhancement.
 */
#define XP_PNTYPE_STD			0x0001
#define XP_PNTYPE_SKETCH		0x0002
#define XP_PNTYPE_WRKMGR		0x0004	/* Tentative */
#define XP_PNTYPE_PDA			0x0008	/* Tentative */

/*========================================================================
 * Error Codes
 *=======================================================================*/
#define XP_E_SUCCESS					0
#define XP_E_FAILURE					1

#define XP_E_FILE_EXIST				2

/*
 * Colormap handling return codes - see colors.c
 */
#define XP_VISUAL_NOT_SUPPORTED		100
#define XP_CMAP_SMALL_IMMUTABLE		101
#define XP_CMAP_BIG_IMMUTABLE			102
#define XP_CMAP_OK						103



/*========================================================================
 * Tool Tips - the order of these needs to be the same - the IDs map to
 * the text strings in a static character array in tooltips.c
 *=======================================================================*/
#define XP_TTID_DIR					0
#define XP_TTID_PRJ_TEXT			1
#define XP_TTID_AUDIO_REP			2
#define XP_TTID_AUDIO_TOG			3
#define XP_TTID_PILOT_ADDR			4
#define XP_TTID_PILOT_ADDR_S		5
#define XP_TTID_PILOT_MFET			6
#define XP_TTID_PILOT_MPRO			7
#define XP_TTID_PILOT_MEMO			8
#define XP_TTID_ENV_SAVE_FROM		9
#define XP_TTID_ENV_LOAD_TO		10
#define XP_TTID_PRJ_SAVE			11
#define XP_TTID_PRJ_CANCEL			12
#define XP_TTID_PILOT_FILTER		13
#define XP_TTID_PILOT_SEARCH		14
#define XP_TTID_INSERT_FORMAT		15
#define XP_TTID_INSERT_GMT			16
#define XP_TTID_INSERT_ABBR		17
#define XP_TTID_EMAIL_LIST			18
#define XP_TTID_PILOT_ICAL_SYNC	19
#define XP_TTID_PILOT_ICAL_FETCH	20
#define XP_TTID_PILOT_TODO_FETCH	21
#define XP_TTID_PILOT_TODO_SYNC	22
#define XP_TTID_TODAY				23
#define XP_TTID_FILE					24
#define XP_TTID_CAT_DELETE			25
#define XP_TTID_CAT_MODIFY			26
#define XP_TTID_CAT_ADD				27

#define XP_S_TT_DIR			"Select a Directory"
#define XP_S_TT_FILE			"Name of DB to install, fetch or delete"
#define XP_S_TT_PRJ_TEXT	"Enter or change the\nname of the project"
#define XP_S_TT_AUDIO_REP	"Number of times to play\nthe audio file when\nthe alarm sounds."
#define XP_S_TT_AUDIO_TOG	"Resets all fields\nto current time."
#define XP_S_TT_PILOT_ADDR	"Retrieve Address\ndatabase from Pilot"
#define XP_S_TT_PILOT_ADDR_S	"Upload Address\ndatabase to Pilot"
#define XP_S_TT_PILOT_MFET	"Import: Retrieve memos from Pilot\nExport: Get list of available xnotes"
#define XP_S_TT_PILOT_MPRO	"Import: Convert selected memos into xnotes\nExport: Send selected xnotes to Pilot as memos"
#define XP_S_TT_PILOT_MEMO	"Use Fetch to retrieve xnotes(Export toggle) or\nPilot's memos (Import toggle).  Select items of\ninterest, then use Process to convert to memos\n(Export toggle) or xnotes (Import toggle)."
#define XP_S_TT_ENV_SAVE_FROM "Save text to your id file."
#define XP_S_TT_ENV_LOAD_TO 	\
"Allows you to select from Pilot's\nAddress list, if available. Use the Pilot Tool\n\"Address Fetch\" first to get the list."
#define XP_S_TT_PRJ_SAVE 	"Save changes, but keep window open."
#define XP_S_TT_PRJ_CANCEL "Close window. Any changes not\nsaved previously will be lost."
#define XP_S_TT_PILOT_FILTER "Only show entries from the category selected\nthat contain the search string in the field\nspecifed by the \"Filter On\" menu."
#define XP_S_TT_PILOT_SEARCH "Type search string, hit enter.\nSearch is case insensitive."
#define XP_S_TT_INSERT_FORMAT "Select a format type."
#define XP_S_TT_INSERT_GMT    "Use either GMT or Local time."
#define XP_S_TT_INSERT_ABBR   "Use abbreviated or full\nweekday and month names."
#define XP_S_TT_EMAIL_LIST "Select or type in a email address."
#define XP_S_TT_PILOT_ICAL_SYNC  "Sync appointments to\nyour Pilot calendar."
#define XP_S_TT_PILOT_ICAL_FETCH "Fetch appointments from\nyour Pilot calendar."
#define XP_S_TT_PILOT_TODO_FETCH "Fetch Todos\nfrom Pilot."
#define XP_S_TT_PILOT_TODO_SYNC  "Sync Todos\nto Pilot."
#define XP_S_TT_PILOT_TODAY  "Use today's date\nas a directory name."
#define XP_S_TT_CAT_DELETE  "Delete the currently\nselected category."
#define XP_S_TT_CAT_MODIFY  "Modify the currently\nselected category."
#define XP_S_TT_CAT_ADD     "Add the entry as\na new category."


/*========================================================================
 * Macros
 *=======================================================================*/
#include "xngtk.h"


/*========================================================================
 * Type definitions
 *=======================================================================*/

/*
 * The Calendar Type - we use this to pass information to the calendar
 * window so it can pass back data to the caller and call any external
 * routines when it closes.
 */
typedef struct _calendar_t {
	int			daynum;
	int			monthnum;
	int			yearnum;
	int			hournum;
	int			minnum;
	int			wdnum;
	gpointer		callback;
	gpointer		nodatecb;
	gpointer		cbdata;
} Calendar_T;

/*
 * The Post-It Note record.  One of these is allocated
 * for each note created.
 */

/*
 * The GTK version of the StickyNote structure.
 */
typedef struct _StickyNote {
	GtkWidget	*pn_shellwidget;		/* shell widget holding it all	*/
	GtkWidget	*pn_vbox;				/* vbox inside which other widgets go */
	GtkWidget	*pn_labelwidget;		/* label widget */
	GtkWidget	*pn_savewidget;		/* save widget */
	GtkWidget	*pn_alarmwidget;		/* alarm button */
	GtkWidget	*pn_alarm_pixmapid;	/* alarm pixmap */
	GtkWidget	*pn_anchor_pixmapid;	/* anchor pixmap */
	GtkWidget	*pn_options;			/* options button widget */
	GtkWidget	*pn_optionsmenu;		/* options menu widget */

	GtkWidget	*pn_filebutton; 		/* file button widget */
	GtkWidget	*pn_filemenu; 			/* file menu widget */

	GtkWidget		*pn_textwidget;		/* text widget of the note	*/
	GtkTextBuffer	*pn_textbuffer;		/* text widget of the note	*/
	GtkWidget		*pn_texthbox;			/* text widget parent */
	GtkWidget		*pn_scrollwidget;		/* scroll window for text */

	GtkWidget	*pn_anchorwidget;		/* menu widget for "Anchor" option */
	GtkWidget	*pn_unanchorwidget;	/* menu widget for "UnAnchor" option */
	GtkWidget	*pn_settimewidget;	/* menu widget for "Set Alarm" option */
	GtkWidget	*pn_unsettimewidget;	/* menu widget for "Unset Alarm" option */

	GString	*pn_file;		/* file note will be saved in	*/
	char		*pn_text;		/* buffer holding text of note	*/
	GString	*pn_name;		/* name of note	*/
	char		*pn_project;	/* project id - TBD */
	int		pn_type;			/* Note type: traditional, memo, todo - TBD */
	Calendar_T	pn_caldata;		/* Generic calendar data - not saved */

	gint	pn_index;			/* index number of note		*/
	gint	pn_hide_index;		/* index used when note is hidden */
	gint	pn_shellx;			/* x coord of shell widget	*/
	gint	pn_shelly;			/* y coord of shell widget	*/
	gint	pn_textsize;		/* size of pn_text in chars	*/
	gint	pn_textwidth;		/* width of text widget window	*/
	gint	pn_textheight;		/* height of text widget window	*/

	gint	pn_alarm_mon;		/* alarm month (0-11) */
	gint	pn_alarm_day;		/* alarm day (0-31) */
	gint	pn_alarm_hour;		/* alarm hour (0-23) */
	gint	pn_alarm_min;		/* alarm minute (0-59) */
	char	*pn_alarm_audio;	/* audio file for alarms */
	gint	pn_alarm_repeat;	/* number of times to repeat alarm */
	gint	pn_alarm_volume;	/* alarm volume */

	gboolean	pn_positionit;	/* true if shellx/shelly valid	*/
	gboolean	pn_hidden;		/* true if note is currently hidden */
	gboolean	pn_saved;		/* false=save button sensitive	*/
	gboolean	pn_anchor;		/* true if note is an anchor note */
	gboolean	pn_alarm;		/* true if notes alarm is set */

#ifdef DO_PSPELL
	PspellManager	*spell_checker;	/* class required by Pspell */
#endif

	struct	_StickyNote *pn_next;	/* pointer to next note record	*/
} StickyNote;


/*
 * Envelopes.
 */
typedef struct _StickyEnvelope {
	int		env_id;			/* unique id */
	char		*text;			/* text for envelope */

	struct _StickyEnvelope	*env_next;	/* ptr to next envelope record */
} StickyEnvelope;


/*
 * The resource record, for holding resources specific to xnotes.
 */
typedef struct {
	int		geometryw;		/* Width of the Plaid window */
	int		geometryh;		/* Height of the Plaid window */
	int		buf_size;		/* size of pn_text to be used	*/
	int		interval;		/* auto-save interval (in minutes) */
	char		scroll_ovf;		/* NOT USED ANYMORE */
	char		scroll_bar;		/* turn on scroll bars */
	char		save_notes;		/* save notes on exit */
	char		compatibility;	/* maintain prev version compatibility */
	char		nosave;			/* don't do auto-save */
	char		noalarm;			/* don't do alarms */
	char		nonotice;		/* don't show dialog about disabled functions */
	char		help;				/* provide usage message */
	char		defaults;		/* Show the configured defaults */
	char		version;			/* provide version information */
	int		name_width;		/* used	in calculating width of dialog */
	int		anchor_offset;	/* used in cascading notes */
	char 		*note_dir;		/* path to note directory	*/
	char		*addr_dir;		/* where adddresses are stored */
	char		*xpm_dir;		/* path to xpm files	*/
	char 		*print_cmd;		/* print command (using printf format) */
	char 		*calendar_cmd;	/* calendar command */
	char 		*email_cmd;		/* email command */
	char 		*email_addr;	/* default email address to mail to */
	char 		*home_dir;		/* default home directory */
	char 		*debugfile;		/* debug output file */
	int 		debuglevel;		/* debug level to use */
	char		*config_file;	/* config file name */
	char		*gtk_rc;			/* Gtk rc config file */
	char		*audio_cmd;		/* how to play audio files */
	char		*audio_dir;		/* where audio files are located */
	char		noaudio;			/* turn off audio for alarms */
	char		install;			/* when true, install private colormap */
	char		no_tips;			/* when true, don't use Tool Tips */
	char		*pilot_xfer;	/* NULL if Pilot "xn-xfer" not found */
	char		*pilot_addr;	/* NULL if Pilot "xn-addresses" not found */
	char		*pilot_memos;	/* NULL if Pilot "xn-memos" not found */
	char		*pilot_todo;	/* NULL if Pilot "xn-todos" not found */
	char		*pilot_ical;	/* NULL if Pilot "xn-cal" not found */
	char		*pilot_dir;		/* where pilot backups get stored */
	char		*pilot_port;	/* Local device port to connect to */
	char		*nenscript;		/* nenscript: used to print envelopes */
	char		*spellchecker;	/* should be ispell/aspell compatible */
	char		*browser;		/* browser to use for help files */
} AppRes, *AppResPtr;

/*
 * External commands:  1=enabled, 0=disabled.
 * For every external command we add to AppRes, we need an entry 
 * in this structure too.
 */
typedef struct {
	int		print;
	int		calendar;
	int		email;
	int		audio;
	int		pilot_xfer;
	int		pilot_addr;
	int		pilot_memos;
	int		pilot_todo;
	int		pilot_ical;
	int		nenscript;
	int		spellchecker;
	int		browser;
} ExternalCmds;

/*
 * Project configuration information.
 */
typedef struct _project_type{
	int	id;			/* unique id */
	gdouble	color[4];/* background color for notes in this project */
	char		*name;	/* name to use for this project */
	char		*dir;		/* directory to use for this project's notes */
	struct _project_type	*next;
} ProjectType;

/*
 * Audio file configuration information.
 */
typedef struct _af {
	int			id;		/* unique index */
	char			*file;	/* audio file name */
	char			type;		/* audio file type */
	struct _af	*next;	/* pointer to next link */
} AudioFileType;

/*
 * The list of hidden notes
 */
typedef struct {
	gchar			*name;	/* string used in menu button */
	GtkWidget	*widget;	/* button in menu for hidden note */
} ItemList;

/*
 * link lists of notes
 */
typedef struct pnlinks{
	StickyNote	*pn;
	int			x;			/* x coord of last note */
	int			y;			/* y coord of last note */
	struct pnlinks	*next;
}PNLinks;

/*
 * Upper or Lower case request types for ALConvertCase()
 */
typedef enum {
	AL_UPPER,
	AL_LOWER
} AL_CASE_TYPE;

/*
 * PailmPilot Address records.
 */
typedef struct _pilotaddr_t {
	struct _pilotaddr_t		*next;
	char	*last;
	char	*first;
	char	*title;
	char	*company;
	char	*phoneLabel1;
	char	*phone1;
	char	*phoneLabel2;
	char	*phone2;
	char	*phoneLabel3;
	char	*phone3;
	char	*phoneLabel4;
	char	*phone4;
	char	*phoneLabel5;
	char	*phone5;
	char	*address;
	char	*city;
	char	*state;
	char	*zip;
	char	*country;
	char	*custom1;
	char	*custom2;
	char	*custom3;
	char	*custom4;
	char	*note;
	char	*category;
	char	*listPhone;
	int	attributes;
	int	recordid;
} PilotAddr_T;

/*
 * PalmPilot Category records.
 */
typedef struct _pilotcategory_t {
	struct _pilotcategory_t	*next;
	char	*name;
} PilotCategory_T;

/*
 * Pilot Todo List Records.
 */
typedef struct _pilottodo_t {
	struct _pilottodo_t		*next;
	int			indefinite;
	int			private;
	int			recordid;
	int			priority;
	int			completed;
	char			*category;
	char			*due_date;
	char			*title;
	char			*note;
} PilotTodo_T;

/*
 * Pilot Memo Records.
 */
typedef struct _pilotmemo_t {
	struct _pilotmemo_t		*next;
	int			recordid;
	int			xnotesid;
	int			attributes;
	char			*category;
	char			*title;
	char			*text;
} PilotMemo_T;


/*
 * Pilot Appointment Records.
 */
#define XP_PA_REPEATNONE		0
#define XP_PA_REPEATDAILY		1
#define XP_PA_REPEATWEEKLY		2
#define XP_PA_REPEATMONTHLY	3
#define XP_PA_REPEATNOTSUPPORTED	4
#define XP_PA_REPEATYEARLY		5
typedef struct _pilotappt_t {
	struct _pilotappt_t		*next;
	int			recordid;
	int			attributes;
	int 			event;
	struct tm 	begin;
	struct tm 	end;
	int 			alarm;
	int 			advance;
	int 			advanceUnits;
	int 			repeatType;
	int 			repeatForever;
	struct tm 	repeatEnd;
	int 			repeatFrequency;
	int 			repeatDay;
	int 			repeatDays[7];
	int 			repeatWeekstart;
	int 			exceptions;
	struct tm 	*exception;
	char 			*description;
	char 			*note;
} PilotAppt_T;

typedef struct _monthly_cell {
	int				date[2];
	PilotAppt_T		*linkptr;
} MonthlyCell_T;

/*
 * Tracking visible list of addresses in Address Manager.
 */
typedef struct _listentries_t {
	struct _listentries_t	*next;
	PilotAddr_T					*linkptr;
	int							id;
} ListEntries_T;

/*
 * GTK can't run a widgets list of children in 1.0.1.  So generic.c needs
 * a datastructure to pass back widget ids.
 */
typedef struct _gshell_t {
	GtkWidget	*shell_id;
	GtkWidget	*vbox;
	GtkWidget	*accept;
	GtkWidget	*print;
	GtkWidget	*search;
	GtkWidget	*cancel;
	GtkWidget	*overwrite;
	GtkWidget	*append;
	GtkWidget	*help;
	GList			*linkhdr;	/* Link list of GMenuData_T's */
} GShell_T;

/*
 * Information for menus passed to the Generic Shell function (generic.c)
 */
typedef struct _gmenudata_t {
	int			menu_id;		/* Which menu does it go in? */
	char			*label;		/* What is the menu label? */
	gpointer		cb;			/* What function will be called when selected? */
	GtkWidget	*widget;		/* Widget allocated for this item */
} GMenuData_T;

/* Used in generic.c to build menus. */
typedef struct _gmenus_t {
	GtkWidget	*widget[4];  /* The 4 menus we allow */
	char			*names[4];   /* The names of those menus */
} GMenus_T;

/*
 * Spell checker structures for saving ispell/aspell output.
 */
typedef struct _spellcheck_t {
	struct _spellcheck_t	*next;
	char	*original;
	int	count;
	int	offset;
	char	*misslist;
} SpellCheck_T;


/*
 * External variable declarations.
 */
extern	AppRes app_res;
extern	unsigned long timer_interval;
extern	unsigned long alarm_interval;

extern	GtkWidget *listwidget;
extern	GtkWidget *menuwidget;
extern	GtkWidget *plaidwidget;

/*
 * If you're SYSV system doesn't have bcopy(), bzero(), or rindex()
 */
#ifdef SYSV_USE_MEMSET
#undef bzero
#define bzero(a,b) memset(a,0,b)
#undef bcopy
#define bcopy(a,b,c) memcpy(b,a,c)
#undef rindex
#define rindex(a,b) strrchr(a,b)
#else
 extern char *rindex();
#endif /* SYSV_USE_MEMSET */


/*========================================================================
 * Include all other header files here.   Makes it easier on the rest
 * of the .c files.
 *=======================================================================*/
#include "prototypes.h"
#include "version.h"
#include "err_text.h"
#include "XNgetopt.h"

#endif /* XP_H */
